CommandReceipt

Struct CommandReceipt 

pub struct CommandReceipt {
    pub exit_status: ExitStatus,
    pub gas_used: u64,
    pub return_values: Vec<u8>,
    pub logs: Vec<Log>,
}
A CommandReceipt summarizes the result of execution of a Command.

Fields

exit_status: ExitStatus

Exit status tells whether the corresponding command in the sequence succeeded in doing its operation, and, if it failed, whether the failure is because of gas exhaustion or some other reason.

gas_used: u64

How much gas was used in the execution of the transaction. This will at most be the transaction’s gas limit.

return_values: Vec<u8>

The return value of the corresponding command.

logs: Vec<Log>

The logs emitted during the corresponding call command.