pub struct BlockHashByHeightResponse {
pub block_height: BlockHeight,
pub block_hash: Option<CryptoHash>,
}Fields
block_height: BlockHeightblock_hash: Option<CryptoHash>Trait Implementations
Sourceimpl BorshDeserialize for BlockHashByHeightResponse
impl BorshDeserialize for BlockHashByHeightResponse
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for BlockHashByHeightResponse
impl Clone for BlockHashByHeightResponse
Sourcefn clone(&self) -> BlockHashByHeightResponse
fn clone(&self) -> BlockHashByHeightResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockHashByHeightResponse
impl Debug for BlockHashByHeightResponse