pub struct BlockHeightByHashRequest {
pub block_hash: CryptoHash,
}Expand description
Get the height of the block with a given block hash.
Fields
block_hash: CryptoHashTrait Implementations
Sourceimpl BorshDeserialize for BlockHeightByHashRequestwhere
CryptoHash: BorshDeserialize,
impl BorshDeserialize for BlockHeightByHashRequestwhere
CryptoHash: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BlockHeightByHashRequestwhere
CryptoHash: BorshSerialize,
impl BorshSerialize for BlockHeightByHashRequestwhere
CryptoHash: BorshSerialize,
Sourceimpl Clone for BlockHeightByHashRequest
impl Clone for BlockHeightByHashRequest
Sourcefn clone(&self) -> BlockHeightByHashRequest
fn clone(&self) -> BlockHeightByHashRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockHeightByHashRequest
impl Debug for BlockHeightByHashRequest