pub struct BlockHeightByHashResponse {
pub block_hash: CryptoHash,
pub block_height: Option<BlockHeight>,
}Fields
block_hash: CryptoHashblock_height: Option<BlockHeight>Trait Implementations
Sourceimpl BorshDeserialize for BlockHeightByHashResponse
impl BorshDeserialize for BlockHeightByHashResponse
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for BlockHeightByHashResponse
impl Clone for BlockHeightByHashResponse
Sourcefn clone(&self) -> BlockHeightByHashResponse
fn clone(&self) -> BlockHeightByHashResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockHeightByHashResponse
impl Debug for BlockHeightByHashResponse