pub struct PoolsRequest {
pub operators: HashSet<Operator>,
pub include_stakes: bool,
}Expand description
Get a set of pools.
Fields
operators: HashSet<Operator>include_stakes: boolTrait Implementations
Sourceimpl BorshDeserialize for PoolsRequest
impl BorshDeserialize for PoolsRequest
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for PoolsRequest
impl BorshSerialize for PoolsRequest
Sourceimpl Clone for PoolsRequest
impl Clone for PoolsRequest
Sourcefn clone(&self) -> PoolsRequest
fn clone(&self) -> PoolsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PoolsRequest
impl Debug for PoolsRequest
Sourceimpl Deserializable for PoolsRequest
impl Deserializable for PoolsRequest
Sourceimpl Serializable for PoolsRequest
impl Serializable for PoolsRequest