Struct pchain_types::runtime::SetDepositSettingsInput
source · pub struct SetDepositSettingsInput { /* private fields */ }Trait Implementations
sourceimpl BorshDeserialize for SetDepositSettingsInputwhere
PublicAddress: BorshDeserialize,
bool: BorshDeserialize,
impl BorshDeserialize for SetDepositSettingsInputwhere PublicAddress: BorshDeserialize, bool: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for SetDepositSettingsInputwhere
PublicAddress: BorshSerialize,
bool: BorshSerialize,
impl BorshSerialize for SetDepositSettingsInputwhere PublicAddress: BorshSerialize, bool: BorshSerialize,
sourceimpl Clone for SetDepositSettingsInput
impl Clone for SetDepositSettingsInput
sourcefn clone(&self) -> SetDepositSettingsInput
fn clone(&self) -> SetDepositSettingsInput
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SetDepositSettingsInput
impl Debug for SetDepositSettingsInput
sourceimpl PartialEq<SetDepositSettingsInput> for SetDepositSettingsInput
impl PartialEq<SetDepositSettingsInput> for SetDepositSettingsInput
sourcefn eq(&self, other: &SetDepositSettingsInput) -> bool
fn eq(&self, other: &SetDepositSettingsInput) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for SetDepositSettingsInput
impl StructuralEq for SetDepositSettingsInput
impl StructuralPartialEq for SetDepositSettingsInput