pub struct WithdrawDepositInput {
pub operator: PublicAddress,
pub max_amount: u64,
}Fields
operator: PublicAddressThe address of operator of the target pool
max_amount: u64The amount of deposits that the stake owner wants to withdraw. The prefix ‘max’ is denoted here because the actual withdrawal amount can be less than the wanted amount.