Struct pchain_types::runtime::WithdrawDepositInput
source · pub struct WithdrawDepositInput { /* private fields */ }Trait Implementations
sourceimpl BorshDeserialize for WithdrawDepositInputwhere
PublicAddress: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for WithdrawDepositInputwhere PublicAddress: BorshDeserialize, u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for WithdrawDepositInputwhere
PublicAddress: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for WithdrawDepositInputwhere PublicAddress: BorshSerialize, u64: BorshSerialize,
sourceimpl Clone for WithdrawDepositInput
impl Clone for WithdrawDepositInput
sourcefn clone(&self) -> WithdrawDepositInput
fn clone(&self) -> WithdrawDepositInput
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for WithdrawDepositInput
impl Debug for WithdrawDepositInput
sourceimpl PartialEq<WithdrawDepositInput> for WithdrawDepositInput
impl PartialEq<WithdrawDepositInput> for WithdrawDepositInput
sourcefn eq(&self, other: &WithdrawDepositInput) -> bool
fn eq(&self, other: &WithdrawDepositInput) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serializable for WithdrawDepositInput
impl Serializable for WithdrawDepositInput
impl Eq for WithdrawDepositInput
impl StructuralEq for WithdrawDepositInput
impl StructuralPartialEq for WithdrawDepositInput